@@ -11,7 +11,11 @@
 #' @import ggplot2
 #' @importFrom lubridate ymd_hms
 #' @importFrom tidyr gather
+#' @importFrom tidyr spread
 #' @import XML
+#' @import xml2
+#' @importFrom data.table data.table
+#' @importFrom data.table :=
 #' @import dplyr
 #' @importFrom stats median
 #' @importFrom stats na.omit
@@ -23,10 +27,12 @@
 #' @importFrom utils data
 
 
-globalVariables(c("event_classifier", "activity_instance_classifier", "absolute_frequency", "Freq","q1", "q3","st_dev",
+globalVariables(c(".N","event_classifier", "activity_instance_classifier", "absolute_frequency", "Freq","q1", "q3","st_dev",
 				  "relative_trace_frequency", "case_classifier", "timestamp_classifier", "last_event", "absolute", "cum_sum", "event_concept.name",				  "event_time.timestamp", "case_concept.name", "first_event", "duration_in_days", "conditions_valid", "starts_with",
 				  "duration", "start_timestamp","complete_timestamp", "complete","e","r","min_timestamp","max_rank","trace_id","act_freq",
 				  "s","dur","start", "relative_frequency","tot_dur","number_of_repetitions","denom", "instance",
-				  "total_length","perc", "relative","activity_frequency","absolute_trace_coverage","instances","cnt", "trace_frequency"))
+				  "total_length","perc", "relative","activity_frequency","absolute_trace_coverage","instances",
+				  "cnt", "trace_frequency", "V1","V2",".","event_id","freq", "element_type"))
+
 
 NULL
